@@ -20,6 +20,7 @@ DLL32 = "/DLL/32Bit/"
 DLL64 = "/DLL/64Bit/"
 
 def _load_cdll(path, name):
+    relPath = ""
     if sys.platform.startswith("linux"):
         ext_suffix = ".so"
     elif sys.platform.startswith("darwin"):
@@ -28,16 +29,18 @@ def _load_cdll(path, name):
         if(sizeof(c_void_p) == 4):
             os.add_dll_directory(os.path.dirname(__file__) + DLL32)
             ext_suffix = "-32.dll"
+            relPath = DLL32
         else:
             os.add_dll_directory(os.path.dirname(__file__) + DLL64)
             ext_suffix = "-64.dll"
+            relPath = DLL64
     else:
         raise RuntimeError(
             'Platform "{}" not recognized while trying to resolve shared library'.format(
                 sys.platform))
 
-    library_format = "{}{}" if platform.system() == "Windows" else "lib{}{}"
-    library_path = os.path.join(path, library_format.format(name, ext_suffix))
+    library_format = "{}{}{}" if platform.system() == "Windows" else "{}lib{}{}"
+    library_path = os.path.join(path, library_format.format(relPath, name, ext_suffix))
 
     try:
         return cdll.LoadLibrary(library_path)
